4. Signals — django SHOP 0.1.1.dev0 documentation

### Navigation

- index
- modules |
- next |
- previous |
- django SHOP 0.1.1.dev0 documentation »

# 4. Signals

## 4.1. Order

The `shop.order_signals` module defines signals that are emitted during the checkout process

Warning

Currently, not all signals are emitted inside of django SHOP. This may change in the future.

### 4.1.1. `processing`

`shop.order_signals.` `processing`

Emitted when the `Cart` instance was converted to an `Order`.

Arguments sent with this signal:

`sender`
  The `Order` model class
`order`
  The `Order` instance
`cart`
  The `Cart` instance

### 4.1.2. `payment_selection`

`shop.order_signals.` `payment_selection`

Emitted when the user is shown the “select a payment method” page.

Arguments sent with this signal:

`sender`
  The `shop.shipping.api.ShippingAPI` instance
`order`
  The `Order` instance

### 4.1.3. `confirmed`

`shop.order_signals.` `confirmed`

Emitted when the user has finished placing his order (regardless of the payment success or failure).

Arguments sent with this signal:

`sender`
  not defined
`order`
  The `Order` instance

Note

This signal is currently not emitted.

### 4.1.4. `completed`

`shop.order_signals.` `completed`

Emitted when payment is received for the `Order`. This signal is emitted by the `shop.views.checkout.ThankYouView`.

Arguments sent with this signal:

`sender`
  The `ThankYouView` instance
`order`
  The `Order` instance

### 4.1.5. `cancelled`

`shop.order_signals.` `cancelled`

Emitted if the payment was refused or another fatal problem occurred.

Arguments sent with this signal:

`sender`
  not defined
`order`
  The `Order` instance

Note

This signal is currently not emitted.

### 4.1.6. `shipped`

`shop.order_signals.` `shipped`

Emitted (manually) when the shop clerk or robot shipped the order.

Arguments sent with this signal:

`sender`
  not defined
`order`
  The `Order` instance

Note

This signal is currently not emitted.

### Navigation

- index
- modules |
- next |
- previous |
- django SHOP 0.1.1.dev0 documentation »